require 'sidekiq/web'

Rails.application.routes.draw do
  devise_for :users

  get 'welcome', to: 'welcome#index'
  get 'check_your_email', to: 'welcome#check_your_email'

  get 'signup', to: 'signup#index'
  match 'signup/:step', to: 'signup#steps', as: :signup_steps, via: [:get, :post]
  post 'signup_validate', to: 'signup#validate'

  get 'settings', to: 'settings#index'
  post 'settings_reset_password', to: 'settings#reset_password'

  get 'security', to: 'security#index'

  resources :invitations, only: ['index', 'show', 'create', 'destroy']

  resources :donations

  get 'wallet', to: 'wallet#index'
  get 'wallet/transactions', to: 'wallet#transactions'

  get 'lnurlpay/:address', to: 'lnurlpay#index', constraints: { address: /[^\/]+/}
  get 'lnurlpay/:address/invoice', to: 'lnurlpay#invoice', constraints: { address: /[^\/]+/}

  namespace :admin do
    root to: 'dashboard#index'
    get 'invitations', to: 'invitations#index'
    get 'ldap_users', to: 'ldap_users#index'
    resources :donations
  end

  authenticate :user, ->(user) { user.is_admin? } do
    mount Sidekiq::Web => '/sidekiq'
  end

  # Letter Opener (open "sent" emails in dev and staging)
  if Rails.env.match(/staging|development/)
    mount LetterOpenerWeb::Engine, at: "letter_opener"
  end

  root to: 'dashboard#index'
end
